#!/bin/bash

# fixetc
# The purpose of this script is to fix any problems that were caused 
# by using the old CornellExtensions and MavericksExtensions scripts.
# These scripts modified /etc in a way that can cause problems.  This
# script undoes those errors. 
# This script should be run first.

found=0

# Warn the student if we need sudo
function display_instructions {
    echo ""
    echo "IMPORTANT: You must enter your password to fix a (minor) problem."
    echo "When you type your password, it will not echo (e.g. it will look"
    echo "like nothing is happening).  Hit RETURN after you enter your password."
    echo ""
    found=1
}

# Fix the profile file
function fix_profile {
    remove_folder $1
    if [ ! -e $1 ]; then
        if [ "$found" -eq "0" ]; then
            display_instructions
        fi
        sudo touch $1
        sudo /usr/sbin/chown root:wheel $1
        sudo chmod a+w $1
        echo "# System-wide .profile for sh(1)" >> $1
        echo "" >> $1
        echo "if [ -x /usr/libexec/path_helper ]; then" >> $1
        echo '	eval `/usr/libexec/path_helper -s`' >> $1
        echo "fi" >> $1
        echo "" >> $1
        echo 'if [ "${BASH-no}" != "no" ]; then' >> $1
        echo "	[ -r /etc/bashrc ] && . /etc/bashrc" >> $1
        echo "fi" >> $1
        sudo chmod 444 $1        
    fi
}

# Fix the bashrc file
function fix_bashrc {
    remove_folder $1
    if [ ! -e $1 ]; then
        if [ "$found" -eq "0" ]; then
            display_instructions
        fi
        sudo touch $1
        sudo /usr/sbin/chown root:wheel $1
        sudo chmod a+w $1
        echo "# System-wide .bashrc file for interactive bash(1) shells." >> $1
        echo "if [ -z \"\$PS1\" ]; then" >> $1
        echo "   return" >> $1
        echo "fi" >> $1
        echo "" >> $1
        echo "PS1='\\h:\\W \\u\\\$ '" >> $1
        echo "# Make bash check its window size after a process completes" >> $1
        echo "shopt -s checkwinsize" >> $1
        echo "# Tell the terminal about the working directory at each prompt." >> $1
        echo "if [ \"\$TERM_PROGRAM\" == \"Apple_Terminal\" ] && [ -z \"\$INSIDE_EMACS\" ]; then" >> $1
        echo "    update_terminal_cwd() {" >> $1
        echo "        # Identify the directory using a \"file:\" scheme URL," >> $1
        echo "        # including the host name to disambiguate local vs." >> $1
        echo "        # remote connections. Percent-escape spaces." >> $1
        echo "	local SEARCH=' '" >> $1
        echo "	local REPLACE='%20'" >> $1
        echo "	local PWD_URL=\"file://\$HOSTNAME\${PWD//\$SEARCH/\$REPLACE}\"" >> $1
        echo "	printf '\e]7;%s\a' \"\$PWD_URL\"" >> $1
        echo "    }" >> $1
        echo "    PROMPT_COMMAND=\"update_terminal_cwd; \$PROMPT_COMMAND\"" >> $1
        echo "fi" >> $1
        sudo chmod 444 $1        
    fi
}

# Fix the paths file
function fix_paths {
    remove_folder $1
    if [ ! -e $1 ]; then
        if [ "$found" -eq "0" ]; then
            display_instructions
        fi
        sudo touch $1
        sudo /usr/sbin/chown root:wheel $1
        sudo chmod a+w $1
        echo "/usr/bin" >> $1
        echo "/bin" >> $1
        echo "/usr/sbin" >> $1
        echo "/sbin" >> $1
        echo "/usr/local/bin" >> $1
        sudo chmod 444 $1
    fi
}

# Problems causes files to be installed as directories.
function remove_folder {
    if [ -d $1 ]; then
        if [ "$found" -eq "0" ]; then
            display_instructions
        fi
        sudo rm -rf $1
    fi
}

# These are the problem directories
echo "Checking for problems with previous installations..."
fix_profile "/etc/profile"
fix_bashrc "/etc/bashrc"
fix_paths "/etc/paths"
remove_folder "/usr/local/lib/lib"
if  [ "$found" -eq "0" ]; then
    echo "No problems found."
else
    echo "Problems fixed successfully."
fi